@@ -686,9 +686,14 @@ class DuPanShareList:
                     return file_list
         raise RuntimeError("too many attempts")
 
-    def list(self, dir="/", page=1, num=0) -> list[dict]:
+    def listdir_attr(self, dir="/", page=1, num=0) -> list[dict]:
         if dir in ("", "/"):
             data = self.list_index()
+            if num <= 0:
+                return data
+            if page < 1:
+                page = 1
+            return data[(page-1)*num:page*num]
         if not hasattr(self, "share_uk"):
             self.list_index()
         if not dir.startswith("/"):
